@@ -1,7 +1,8 @@
 # -*- coding: UTF-8 -*-
 # Copyright (c) 2018, Thomas Hartmann
 #
-# This file is part of the plus_slurm Project, see: https://gitlab.com/thht/plus-slurm
+# This file is part of the plus_slurm Project,
+# see: https://gitlab.com/thht/plus-slurm
 #
 #    plus_slurm is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -16,5 +17,5 @@
 #    You should have received a copy of the GNU General Public License
 #    along with obob_subjectdb. If not, see <http://www.gnu.org/licenses/>.
 
-from .jobcluster import JobCluster, PermuteArgument
-from .job import Job, AutomaticFilenameJob
+from .jobcluster import JobCluster, PermuteArgument  # noqa
+from .job import Job, AutomaticFilenameJob  # noqa
